==> jc-1.4.0.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24ListenerAdapter.h <==
// class gnu.xml.util.SAXNullTransformerFactory$ListenerAdapter

// class file dependencies
// @dep_class 4a8f28d3ca142213 gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_

// Forward structure declarations
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_TransformerException$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$_init$89bfcd132b564ddd(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object *);

// Virtual methods
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern struct _jc_javax_xml_transform_TransformerException$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$map$f4e8f782c2e8589e(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$map$f4e8f782c2e8589e;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	struct _jc_javax_xml_transform_TransformerException$object	*(*map$f4e8f782c2e8589e)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *);
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs {
	struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object	*transformer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24ListenerAdapter.h <==
// class gnu.xml.util.SAXNullTransformerFactory$ListenerAdapter

// class file dependencies
// @dep_class 4a8f28d3ca142213 gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_

// Forward structure declarations
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_TransformerException$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$_init$89bfcd132b564ddd(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_transform_TransformerException$object *_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$map$f4e8f782c2e8589e(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$map$f4e8f782c2e8589e;
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_transform_TransformerException$object	*(*map$f4e8f782c2e8589e)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vmethods	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs {
	struct _jc_gnu_xml_util_SAXNullTransformerFactory__24NullTransformer$object	*transformer;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24ListenerAdapter_H_ */
